@@ -8,7 +8,7 @@ use Module::Runtime qw(require_module);
 use Carp qw(confess croak);
 use List::Util qw(first);
 
-our $VERSION = '0.22';
+our $VERSION = '0.24';
 
 sub register_types {
   my ($type_definitions, $into, $moose_namespace) = @_;
@@ -44,7 +44,7 @@ sub make_type {
         || croak "Must define a 'from' namespace for the parent type: $subtype_of when defining type: $type_definition->{name}";
       $subtype_of = do {
         no strict 'refs';
-        \&{$from . '::' . $subtype_of};
+        &{$from . '::' . $subtype_of}();
       };
     }
     # Assume a (base) test always exists even if you must write: test => sub {1}
@@ -54,7 +54,9 @@ sub make_type {
       local $@;
       eval { $subtype_of->($value); 1 } or return;
       # TODO implement: eval { $base_test->($value); 1 } paradigm
-      $base_test->($value) or return;
+      if ($base_test) {
+        $base_test->($value) or return;
+      }
       return 1;
     };
   }
